#[non_exhaustive]pub struct ExportAs2805KeyCryptogram {
pub wrapping_key_identifier: String,
pub as2805_key_variant: As2805KeyVariant,
}Expand description
Parameter information for key material export using AS2805 key cryptogram format.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.wrapping_key_identifier: StringA key identifier that can be either a key ARN or an alias name. This allows flexible key identification in operations.
When using a key ARN, it must be a fully qualified ARN in the format: arn:aws:payment-cryptography:region:account:key/key-id.
When using an alias, it must begin with alias/ followed by the alias name.
Do not include confidential or sensitive information in this field. This field may be displayed in plaintext in CloudTrail logs and other output.
as2805_key_variant: As2805KeyVariantThe cryptographic usage of the key under export.
Implementations
Sourceimpl ExportAs2805KeyCryptogram
impl ExportAs2805KeyCryptogram
Sourcepub fn wrapping_key_identifier(&self) -> &str
pub fn wrapping_key_identifier(&self) -> &str
A key identifier that can be either a key ARN or an alias name. This allows flexible key identification in operations.
When using a key ARN, it must be a fully qualified ARN in the format: arn:aws:payment-cryptography:region:account:key/key-id.
When using an alias, it must begin with alias/ followed by the alias name.
Do not include confidential or sensitive information in this field. This field may be displayed in plaintext in CloudTrail logs and other output.
Sourcepub fn as2805_key_variant(&self) -> &As2805KeyVariant
pub fn as2805_key_variant(&self) -> &As2805KeyVariant
The cryptographic usage of the key under export.
Sourceimpl ExportAs2805KeyCryptogram
impl ExportAs2805KeyCryptogram
Sourcepub fn builder() -> ExportAs2805KeyCryptogramBuilder
pub fn builder() -> ExportAs2805KeyCryptogramBuilder
Creates a new builder-style object to manufacture ExportAs2805KeyCryptogram.